commit 2bc8e1cf9c548ef8c390fe47f302db77078cf39b
Author: Cliff Brake <cbrake@bec-systems.com>
Date:   Fri Feb 4 17:37:37 2011 -0500

    enable NAND ECC engine

diff --git a/drivers/k9f1g08r0a.c b/drivers/k9f1g08r0a.c
index 7b5fff8..9710e2f 100644
--- a/drivers/k9f1g08r0a.c
+++ b/drivers/k9f1g08r0a.c
@@ -58,7 +58,7 @@
 #define OOB_SIZE		64
 #define MAX_NUM_PAGES		64
 
-#define ECC_CHECK_ENABLE
+//#define ECC_CHECK_ENABLE
 #define ECC_SIZE		24
 #define ECC_STEPS		3
 
@@ -179,6 +179,25 @@ int nand_readid(int *mfr, int *id)
 	return 0;
 }
 
+void set_on_die_ecc()
+{
+	printf("Enable Micron on-die ECC engine\n");
+	int i,addr = 0x90;
+	u16 data_out = 0x8;
+	/* MICRON Send CMD #EF ADDR 08 00 00 00 */
+	if (NanD_Command(NAND_CMD_SET_FEATURES)) {
+		printf("ERROR: On-Die ECC\n");
+	}
+
+	NanD_Address(1, addr);
+	delay(100);
+	for(i=0; i<8; i++,data_out=0x0)
+		WRITE_NAND(data_out, NAND_ADDR);
+
+	delay(1000);
+	return;
+}
+
 /* read chip mfr and id
  * return 0 if they match board config
  * return 1 if not
@@ -206,6 +225,8 @@ int nand_chip()
 	mfr = READ_NAND(NAND_ADDR);
 	id = READ_NAND(NAND_ADDR);
 
+	set_on_die_ecc();
+
 	NAND_DISABLE_CE();
 
 	printf("NAND chip: mfr is 0x%02x, id is 0x%02x\n", mfr, id);
@@ -234,7 +255,7 @@ int nand_read_block(unsigned char *buf, ulong block_addr)
 {
 	int i, offset = 0;
 
-#ifdef ECC_CHECK_ENABLE
+//#ifdef ECC_CHECK_ENABLE
 	u16 oob_buf[OOB_SIZE >> 1];
  	
 	/* check bad block */
@@ -243,7 +264,7 @@ int nand_read_block(unsigned char *buf, ulong block_addr)
 		printf("Skipped bad block at 0x%x\n", block_addr);
 		return 1;    /* skip bad block */
 	}
-#endif
+//#endif
 	/* read the block page by page*/
 	for (i=0; i<MAX_NUM_PAGES; i++){
 		if (nand_read_page(buf+offset, block_addr + offset))
@@ -279,7 +300,7 @@ static int nand_read_page(u_char *buf, ulong page_addr)
 	NAND_WAIT_READY();
 
 	/* A delay seems to be helping here. needs more investigation */
-	delay(10000);
+	delay(20000);
 	len = (bus_width == 16) ? PAGE_SIZE >> 1 : PAGE_SIZE;
 	p = buf;
 	for (cntr = 0; cntr < len; cntr++){
@@ -341,7 +362,7 @@ static int nand_read_oob(u_char *buf, ulong page_addr)
 	NAND_WAIT_READY();
 
 	/* A delay seems to be helping here. needs more investigation */
-	delay(10000);
+	delay(20000);
 	for (cntr = 0; cntr < len; cntr++)
 		*p++ = READ_NAND(NAND_ADDR);
   
diff --git a/include/common.h b/include/common.h
index 5a6f4c9..78bcdbb 100644
--- a/include/common.h
+++ b/include/common.h
@@ -75,6 +75,8 @@ void 	udelay (unsigned long usec);
 #define NAND_CMD_READOOB	0x50
 #define NAND_CMD_STATUS		0x70
 #define NAND_CMD_READID		0x90
+#define NAND_CMD_GET_FEATURES	0xee
+#define NAND_CMD_SET_FEATURES	0xef
 #define NAND_CMD_RESET		0xff
 
 /* Extended Commands for Large page devices */
